@@ -1,4 +1,4 @@
-## Copyright 2011-2013 Sebastian Gibb
+## Copyright 2011-2014 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -31,51 +31,8 @@
 ##  a matrix of the estimate baseline (col1: mass; col2: intensity)
 ##
 
-## C version
 .estimateBaselineConvexHull <- function(x, y) {
-  n <- length(x)
-  y <- .C("R_lowerConvexHull",
-          as.double(x),
-          as.double(y),
-          as.integer(n),
-          output=double(n),
-          DUP=TRUE,
-          PACKAGE="MALDIquant")$output
-  return(cbind(x, y))
-}
-
-## R only: obsolete because too slow
-.lowerConvexHullR <- function(x, y) {
-
-  ## .left()
-  ## build cross product of 2 vectors and compare to zero
-  ## returns true for >= P2(x2, y2) left/on the line of P0->P1
-  .left <- function(x0, y0, x1, y1, x2, y2) {
-    return(((x1-x0)*(y2-y0) - (x2-x0)*(y1-y0)) > 0)
-  }
-
-  # typically x values have to been sorted
-  # our x values are already sorted
-  index <- double(length(x))
-  k <- 1
-
-  for (i in seq(along=x)) {
-    while (k > 2 && !.left(x[index[k-2]], y[index[k-2]],
-                           x[index[k-1]], y[index[k-1]],
-                           x[i], y[i])) {
-      ## remove last point
-      k <- k-1
-    }
-    index[k] <- i
-    k <- k+1
-  }
-
-  index <- index[1:(k-1)]
-
-  b <- matrix(.unlist(approx(x=x[index], y=y[index], xout=x, method="linear",
-                             rule=2)), nrow=length(x), ncol=2,
-              dimnames=list(list(), list("x", "y")))
-  return(b)
+  return(cbind(x=x, y=.Call("C_lowerConvexHull", x, y)))
 }
 
 ## estimateBaselineMedian
@@ -89,10 +46,10 @@
 ## returns:
 ##  a matrix of the estimate baseline (col1: mass; col2: intensity)
 ##
-.estimateBaselineMedian <- function(x, y, halfWindowSize=100) {
+.estimateBaselineMedian <- function(x, y, halfWindowSize=100L) {
   .stopIfNotIsValidHalfWindowSize(halfWindowSize=halfWindowSize, n=length(x))
 
-  y <- runmed(y, k=2*halfWindowSize+1)
+  y <- runmed(y, k=2L*halfWindowSize+1L)
 
   return(cbind(x, y))
 }
@@ -109,42 +66,26 @@
 ##  ISSN 0168-583X. doi:10.1016/0168-583X(88)90063-8.
 ##  URL http://www.sciencedirect.com/science/article/B6TJN-46YSYTJ-30/2/e0d015ceb8ea8a7bc0702a857a19750b
 ##
+##  decreasing clipping window adapted from:
+##  M. Morhac. 2009.
+##  "An algorithm for determination of peak regions and baseline elimination in
+##   spectroscopic data."
+##  Nuclear Instruments and Methods in Physics Research Section A:
+##  Accelerators, Spectrometers, Detectors and Associated Equipment, 600(2), 478-487.
+##  ISSN 0168-9002. doi:10.1016/S0168-9002(97)01023-1.
+##  URL http://www.sciencedirect.com/science/article/pii/S0168900297010231
+##
 ## params:
 ##  x: vector of x values (only needed for create a matrix as return value)
 ##  y: vector of y values
 ##  iterations: number of iterations
+##  decreasing: use a decreasing clipping window
 ##
 ## returns:
 ##  a matrix of the estimate baseline (col1: mass; col2: intensity)
 
-## C version
-.estimateBaselineSnip <- function(x, y, iterations=100) {
-  n <- length(y)
-  y <- .C("R_snip",
-          as.double(y),
-          as.integer(n),
-          as.integer(iterations),
-          output=double(n),
-          DUP=TRUE,
-          PACKAGE="MALDIquant")$output
-  return(cbind(x, y))
-}
-
-## R only: obsolete because too slow
-.snipR <- function(x, y, iterations=100) {
-  n <- length(y)
-
-  for (i in seq(from=1, to=iterations)) {
-    j <- (i+1):(n-i)
-    jl <- j-i
-    ju <- j+i
-    m <- (y[jl]+y[ju])/2
-    ## too slow
-    #y[j] <- ifelse(y[j] > m, m, y[j])
-    ml <- y[j]>m
-    y[j][ml] <- m[ml]
-  }
-  return(cbind(x, y))
+.estimateBaselineSnip <- function(x, y, iterations=100L, decreasing=TRUE) {
+  return(cbind(x=x, y=.Call("C_snip", y, iterations, decreasing)))
 }
 
 ## estimateBaselineTopHat
@@ -158,7 +99,7 @@
 ## returns:
 ##  a matrix of the estimate baseline (col1: mass; col2: intensity)
 ##
-.estimateBaselineTopHat <- function(x, y, halfWindowSize=100) {
+.estimateBaselineTopHat <- function(x, y, halfWindowSize=100L) {
 
   .stopIfNotIsValidHalfWindowSize(halfWindowSize=halfWindowSize, n=length(x))
 
@@ -168,19 +109,3 @@
   return(cbind(x, y))
 }
 
-## R only: obsolete because too slow
-.topHatR <- function(x, y, halfWindowSize=100) {
-
-  .stopIfNotIsValidHalfWindowSize(halfWindowSize=halfWindowSize, n=length(x))
-
-  windowSize <- 2*halfWindowSize+1
-
-  windows <- embed(c(rep(y[1], halfWindowSize), y,
-                     rep(tail(y, 1), halfWindowSize)), windowSize)
-  e <- apply(windows, 1, min)
-  windows <- embed(c(rep(e[1], halfWindowSize), e,
-                     rep(tail(e, 1), halfWindowSize)), windowSize)
-  y <- apply(windows, 1, max)
-  return(cbind(x, y))
-}
-
